=== modified file 'client/mysql.cc'
--- client/mysql.cc	2008-07-15 00:27:12 +0000
+++ client/mysql.cc	2008-07-15 08:57:01 +0000
@@ -35,6 +35,7 @@
 #ifndef __GNU_LIBRARY__
 #define __GNU_LIBRARY__		      // Skip warnings in getopt.h
 #endif
+#include <readline/history.h>
 #include "my_readline.h"
 #include <signal.h>
 #include <violite.h>
@@ -155,7 +156,9 @@
 static char *full_username=0,*part_username=0,*default_prompt=0;
 static int wait_time = 5;
 static STATUS status;
-static ulong select_limit,max_join_size,opt_connect_timeout=0;
+static uint32_t select_limit;
+static ulong max_join_size;
+static ulong opt_connect_timeout= 0;
 static char mysql_charsets_dir[FN_REFLEN+1];
 static const char *xmlmeta[] = {
   "&", "&amp;",
@@ -995,23 +998,8 @@
 static int         embedded_server_arg_count= 0;
 static char       *embedded_server_args[MAX_SERVER_ARGS];
 static const char *embedded_server_groups[]=
-{ "server", "embedded", "mysql_SERVER", 0 };
-
-/*
- HIST_ENTRY is defined for libedit, but not for the real readline
- Need to redefine it for real readline to find it
-*/
-#if !defined(HAVE_HIST_ENTRY)
-typedef struct _hist_entry {
-  const char      *line;
-  const char      *data;
-} HIST_ENTRY; 
-#endif
-
-extern "C" int add_history(const char *command); /* From readline directory */
-extern "C" int read_history(const char *command);
-extern "C" int write_history(const char *command);
-extern "C" HIST_ENTRY *history_get(int num);
+{ "server", "mysql_SERVER", 0 };
+
 extern "C" int history_length;
 static int not_in_history(const char *line);
 static void initialize_readline (char *name);
@@ -1136,7 +1124,7 @@
   put_info("Welcome to the Drizzle client..  Commands end with ; or \\g.",
 	   INFO_INFO);
   sprintf((char*) glob_buffer.ptr(),
-	  "Your Drizzle connection id is %lu\nServer version: %s\n",
+	  "Your Drizzle connection id is %u\nServer version: %s\n",
 	  mysql_thread_id(&mysql), server_version_string(&mysql));
   put_info((char*) glob_buffer.ptr(),INFO_INFO);
 
@@ -1256,7 +1244,7 @@
     goto err;
 
   /* kill_buffer is always big enough because max length of %lu is 15 */
-  sprintf(kill_buffer, "KILL /*!50000 QUERY */ %lu", mysql_thread_id(&mysql));
+  sprintf(kill_buffer, "KILL /*!50000 QUERY */ %u", mysql_thread_id(&mysql));
   mysql_real_query(kill_mysql, kill_buffer, strlen(kill_buffer));
   mysql_close(kill_mysql);
   tee_fprintf(stdout, "Query aborted by Ctrl+C\n");
@@ -2231,7 +2219,7 @@
 static void initialize_readline (char *name)
 {
   /* Allow conditional parsing of the ~/.inputrc file. */
-  rl_readline_name = name;
+  rl_readline_name= name;
 
   /* Tell the completer that we want a crack first. */
   rl_attempted_completion_function= (rl_completion_func_t*)&new_mysql_completion;
@@ -3112,7 +3100,7 @@
   {
     if (interrupted_query)
       break;
-    ulong *lengths= mysql_fetch_lengths(result);
+    uint32_t *lengths= mysql_fetch_lengths(result);
     (void) tee_fputs("| ", PAGER);
     mysql_field_seek(result, 0);
     for (uint off= 0; off < mysql_num_fields(result); off++)
@@ -3273,9 +3261,9 @@
   {
     if (interrupted_query)
       break;
-    ulong *lengths=mysql_fetch_lengths(result);
+    uint32_t *lengths= mysql_fetch_lengths(result);
     (void) tee_fputs("<TR>", PAGER);
-    for (uint i=0; i < mysql_num_fields(result); i++)
+    for (uint32_t i= 0; i < mysql_num_fields(result); i++)
     {
       (void) tee_fputs("<TD>", PAGER);
       safe_put_field(cur[i],lengths[i]);
@@ -3305,7 +3293,7 @@
   {
     if (interrupted_query)
       break;
-    ulong *lengths=mysql_fetch_lengths(result);
+    uint32_t *lengths= mysql_fetch_lengths(result);
     (void) tee_fputs("\n  <row>\n", PAGER);
     for (uint i=0; i < mysql_num_fields(result); i++)
     {
@@ -3474,7 +3462,7 @@
 {
   MYSQL_ROW	cur;
   MYSQL_FIELD	*field;
-  ulong		*lengths;
+  uint32_t		*lengths;
 
   if (opt_silent < 2 && column_names)
   {
@@ -3489,7 +3477,7 @@
   }
   while ((cur = mysql_fetch_row(result)))
   {
-    lengths=mysql_fetch_lengths(result);
+    lengths= mysql_fetch_lengths(result);
     safe_put_field(cur[0],lengths[0]);
     for (uint off=1 ; off < mysql_num_fields(result); off++)
     {
@@ -3767,7 +3755,7 @@
 
   if (connected)
   {
-    sprintf(buff,"Connection id:    %lu",mysql_thread_id(&mysql));
+    sprintf(buff,"Connection id:    %u",mysql_thread_id(&mysql));
     put_info(buff,INFO_INFO);
     sprintf(buff,"Current database: %.128s\n",
 	    current_db ? current_db : "*** NONE ***");
@@ -4041,8 +4029,8 @@
   {
     char init_command[100];
     sprintf(init_command,
-	    "SET SQL_SAFE_UPDATES=1,SQL_SELECT_LIMIT=%lu,SQL_MAX_JOIN_SIZE=%lu",
-	    select_limit,max_join_size);
+	    "SET SQL_SAFE_UPDATES=1,SQL_SELECT_LIMIT=%u,SQL_MAX_JOIN_SIZE=%u",
+	    select_limit, max_join_size);
     mysql_options(&mysql, MYSQL_INIT_COMMAND, init_command);
   }
   if (default_charset_used)
@@ -4280,7 +4268,7 @@
       }
       if (status.query_start_line && line_numbers)
       {
-	(void) fprintf(file," at line %lu",status.query_start_line);
+	(void) fprintf(file," at line %u",status.query_start_line);
 	if (status.file_name)
 	  (void) fprintf(file," in file: '%s'", status.file_name);
       }

=== modified file 'client/mysqltest.cc'
--- client/mysqltest.cc	2008-07-15 06:45:16 +0000
+++ client/mysqltest.cc	2008-07-15 08:57:01 +0000
@@ -603,7 +603,7 @@
     fprintf(stderr, "=== %s ===\n", query);
     while ((row= mysql_fetch_row(res)))
     {
-      unsigned long *lengths= mysql_fetch_lengths(res);
+      uint32_t *lengths= mysql_fetch_lengths(res);
       row_num++;
 
       fprintf(stderr, "---- %d. ----\n", row_num);
@@ -672,8 +672,8 @@
     fprintf(stderr, "\nWarnings from just before the error:\n");
     while ((row= mysql_fetch_row(res)))
     {
-      unsigned int i;
-      unsigned long *lengths= mysql_fetch_lengths(res);
+      uint32_t i;
+      uint32_t *lengths= mysql_fetch_lengths(res);
 
       if (++row_num >= mysql_num_rows(res))
       {
@@ -1853,8 +1853,8 @@
       and assign that string to the $variable
     */
     DYNAMIC_STRING result;
-    uint i;
-    ulong *lengths;
+    uint32_t i;
+    uint32_t *lengths;
 
     init_dynamic_string(&result, "", 512, 512);
     lengths= mysql_fetch_lengths(res);
@@ -4948,13 +4948,13 @@
 static void append_result(DYNAMIC_STRING *ds, MYSQL_RES *res)
 {
   MYSQL_ROW row;
-  uint num_fields= mysql_num_fields(res);
+  uint32_t num_fields= mysql_num_fields(res);
   MYSQL_FIELD *fields= mysql_fetch_fields(res);
-  ulong *lengths;
+  uint32_t *lengths;
 
   while ((row = mysql_fetch_row(res)))
   {
-    uint i;
+    uint32_t i;
     lengths = mysql_fetch_lengths(res);
     for (i = 0; i < num_fields; i++)
       append_field(ds, i, &fields[i],

=== modified file 'config/ac-macros/readline.m4'
--- config/ac-macros/readline.m4	2008-06-25 05:29:13 +0000
+++ config/ac-macros/readline.m4	2008-07-15 08:57:01 +0000
@@ -18,27 +18,6 @@
     )
 ])
 
-AC_DEFUN([MYSQL_CHECK_LIBEDIT_INTERFACE], [
-    AC_CACHE_CHECK([libedit variant of rl_completion_entry_function], mysql_cv_libedit_interface,
-	AC_TRY_COMPILE(
-	    [
-		#include "stdio.h"
-		#include "readline/readline.h"
-	    ],
-	    [ 
-		char res= *(*rl_completion_entry_function)(0,0);
-		completion_matches(0,0);
-	    ],
-	    [
-		mysql_cv_libedit_interface=yes
-                AC_DEFINE_UNQUOTED([USE_LIBEDIT_INTERFACE], [1],
-                                   [used libedit interface (can we dereference result of rl_completion_entry_function)])
-	    ],
-	    [mysql_cv_libedit_interface=no]
-        )
-    )
-])
-
 AC_DEFUN([MYSQL_CHECK_NEW_RL_INTERFACE], [
     AC_CACHE_CHECK([defined rl_compentry_func_t and rl_completion_func_t], mysql_cv_new_rl_interface,
 	AC_TRY_COMPILE(

=== modified file 'include/drizzle.h'
--- include/drizzle.h	2008-07-14 16:09:55 +0000
+++ include/drizzle.h	2008-07-15 08:57:01 +0000
@@ -207,23 +207,23 @@
   uint64_t affected_rows;
   uint64_t insert_id;		/* id if insert on table with NEXTNR */
   uint64_t extra_info;		/* Not used */
-  unsigned long thread_id;		/* Id for connection in server */
-  unsigned long packet_length;
-  unsigned int	port;
-  unsigned long client_flag,server_capabilities;
-  unsigned int	protocol_version;
-  unsigned int	field_count;
-  unsigned int 	server_status;
-  unsigned int  server_language;
-  unsigned int	warning_count;
+  uint32_t thread_id;		/* Id for connection in server */
+  uint32_t packet_length;
+  uint32_t	port;
+  uint32_t client_flag,server_capabilities;
+  uint32_t	protocol_version;
+  uint32_t	field_count;
+  uint32_t 	server_status;
+  uint32_t  server_language;
+  uint32_t	warning_count;
   struct st_mysql_options options;
   enum mysql_status status;
-  my_bool	free_me;		/* If free in mysql_close */
-  my_bool	reconnect;		/* set to 1 if automatic reconnect */
+  bool	free_me;		/* If free in mysql_close */
+  bool	reconnect;		/* set to 1 if automatic reconnect */
 
   /* session-wide random string */
   char	        scramble[SCRAMBLE_LENGTH+1];
-  my_bool unused1;
+  bool unused1;
   void *unused2, *unused3, *unused4, *unused5;
 
   LIST  *stmts;                     /* list of all statements */
@@ -233,7 +233,7 @@
     Points to boolean flag in MYSQL_RES  or MYSQL_STMT. We set this flag 
     from mysql_stmt_close if close had to cancel result set of this object.
   */
-  my_bool *unbuffered_fetch_owner;
+  bool *unbuffered_fetch_owner;
   /* needed for embedded server - no net buffer to store the 'info' */
   char *info_buffer;
   void *extension;
@@ -245,16 +245,16 @@
   MYSQL_FIELD	*fields;
   MYSQL_DATA	*data;
   MYSQL_ROWS	*data_cursor;
-  unsigned long *lengths;		/* column lengths of current row */
+  uint32_t *lengths;		/* column lengths of current row */
   MYSQL		*handle;		/* for unbuffered reads */
   const struct st_mysql_methods *methods;
   MYSQL_ROW	row;			/* If unbuffered read */
   MYSQL_ROW	current_row;		/* buffer to current row */
   MEM_ROOT	field_alloc;
-  unsigned int	field_count, current_field;
-  my_bool	eof;			/* Used by mysql_fetch_row */
+  uint32_t	field_count, current_field;
+  bool	eof;			/* Used by mysql_fetch_row */
   /* mysql_stmt_close() had to cancel this result */
-  my_bool       unbuffered_fetch_cancelled;  
+  bool       unbuffered_fetch_cancelled;  
   void *extension;
 } MYSQL_RES;
 
@@ -266,8 +266,8 @@
 
 typedef struct st_mysql_parameters
 {
-  unsigned long *p_max_allowed_packet;
-  unsigned long *p_net_buffer_length;
+  uint32_t *p_max_allowed_packet;
+  uint32_t *p_net_buffer_length;
   void *extension;
 } MYSQL_PARAMETERS;
 
@@ -321,38 +321,32 @@
 MYSQL_ROW_OFFSET STDCALL mysql_row_tell(MYSQL_RES *res);
 MYSQL_FIELD_OFFSET STDCALL mysql_field_tell(MYSQL_RES *res);
 
-unsigned int STDCALL mysql_field_count(MYSQL *mysql);
+uint32_t STDCALL mysql_field_count(MYSQL *mysql);
 uint64_t STDCALL mysql_affected_rows(MYSQL *mysql);
 uint64_t STDCALL mysql_insert_id(MYSQL *mysql);
-unsigned int STDCALL mysql_errno(MYSQL *mysql);
+uint32_t STDCALL mysql_errno(MYSQL *mysql);
 const char * STDCALL mysql_error(MYSQL *mysql);
 const char *STDCALL mysql_sqlstate(MYSQL *mysql);
-unsigned int STDCALL mysql_warning_count(MYSQL *mysql);
+uint32_t STDCALL mysql_warning_count(MYSQL *mysql);
 const char * STDCALL mysql_info(MYSQL *mysql);
-unsigned long STDCALL mysql_thread_id(MYSQL *mysql);
+uint32_t STDCALL mysql_thread_id(MYSQL *mysql);
 const char * STDCALL mysql_character_set_name(MYSQL *mysql);
-int          STDCALL mysql_set_character_set(MYSQL *mysql, const char *csname);
+int32_t          STDCALL mysql_set_character_set(MYSQL *mysql, const char *csname);
 
 MYSQL *		STDCALL mysql_init(MYSQL *mysql);
-my_bool		STDCALL mysql_ssl_set(MYSQL *mysql, const char *key,
-				      const char *cert, const char *ca,
-				      const char *capath, const char *cipher);
-const char *    STDCALL mysql_get_ssl_cipher(MYSQL *mysql);
 my_bool		STDCALL mysql_change_user(MYSQL *mysql, const char *user, 
 					  const char *passwd, const char *db);
 MYSQL *		STDCALL mysql_real_connect(MYSQL *mysql, const char *host,
 					   const char *user,
 					   const char *passwd,
 					   const char *db,
-					   unsigned int port,
+					   uint32_t port,
 					   const char *unix_socket,
-					   unsigned long clientflag);
-int		STDCALL mysql_select_db(MYSQL *mysql, const char *db);
-int		STDCALL mysql_query(MYSQL *mysql, const char *q);
-int		STDCALL mysql_send_query(MYSQL *mysql, const char *q,
-					 unsigned long length);
-int		STDCALL mysql_real_query(MYSQL *mysql, const char *q,
-					unsigned long length);
+					   uint32_t clientflag);
+int32_t		STDCALL mysql_select_db(MYSQL *mysql, const char *db);
+int32_t		STDCALL mysql_query(MYSQL *mysql, const char *q);
+int32_t		STDCALL mysql_send_query(MYSQL *mysql, const char *q, uint32_t length);
+int32_t		STDCALL mysql_real_query(MYSQL *mysql, const char *q, uint32_t length);
 MYSQL_RES *     STDCALL mysql_store_result(MYSQL *mysql);
 MYSQL_RES *     STDCALL mysql_use_result(MYSQL *mysql);
 
@@ -377,51 +371,37 @@
 void
 mysql_set_local_infile_default(MYSQL *mysql);
 
-int		STDCALL mysql_shutdown(MYSQL *mysql,
-                                       enum mysql_enum_shutdown_level
-                                       shutdown_level);
-int		STDCALL mysql_dump_debug_info(MYSQL *mysql);
-int		STDCALL mysql_refresh(MYSQL *mysql,
-				     unsigned int refresh_options);
-int		STDCALL mysql_kill(MYSQL *mysql,unsigned long pid);
-int		STDCALL mysql_set_server_option(MYSQL *mysql,
-						enum enum_mysql_set_option
-						option);
-int		STDCALL mysql_ping(MYSQL *mysql);
+int32_t		STDCALL mysql_shutdown(MYSQL *mysql, enum mysql_enum_shutdown_level shutdown_level);
+int32_t		STDCALL mysql_dump_debug_info(MYSQL *mysql);
+int32_t		STDCALL mysql_refresh(MYSQL *mysql, uint32_t refresh_options);
+int32_t		STDCALL mysql_kill(MYSQL *mysql, uint32_t pid);
+int32_t		STDCALL mysql_set_server_option(MYSQL *mysql, enum enum_mysql_set_option option);
+int32_t		STDCALL mysql_ping(MYSQL *mysql);
 const char *	STDCALL mysql_stat(MYSQL *mysql);
 const char *	STDCALL mysql_get_server_info(MYSQL *mysql);
 const char *	STDCALL mysql_get_client_info(void);
-unsigned long	STDCALL mysql_get_client_version(void);
+uint32_t	STDCALL mysql_get_client_version(void);
 const char *	STDCALL mysql_get_host_info(MYSQL *mysql);
-unsigned long	STDCALL mysql_get_server_version(MYSQL *mysql);
-unsigned int	STDCALL mysql_get_proto_info(MYSQL *mysql);
+uint32_t	STDCALL mysql_get_server_version(MYSQL *mysql);
+uint32_t	STDCALL mysql_get_proto_info(MYSQL *mysql);
 MYSQL_RES *	STDCALL mysql_list_dbs(MYSQL *mysql,const char *wild);
 MYSQL_RES *	STDCALL mysql_list_tables(MYSQL *mysql,const char *wild);
 MYSQL_RES *	STDCALL mysql_list_processes(MYSQL *mysql);
-int		STDCALL mysql_options(MYSQL *mysql,enum mysql_option option,
-				      const void *arg);
+int32_t		STDCALL mysql_options(MYSQL *mysql,enum mysql_option option, const void *arg);
 void		STDCALL mysql_free_result(MYSQL_RES *result);
-void		STDCALL mysql_data_seek(MYSQL_RES *result,
-					uint64_t offset);
-MYSQL_ROW_OFFSET STDCALL mysql_row_seek(MYSQL_RES *result,
-						MYSQL_ROW_OFFSET offset);
-MYSQL_FIELD_OFFSET STDCALL mysql_field_seek(MYSQL_RES *result,
-					   MYSQL_FIELD_OFFSET offset);
+void		STDCALL mysql_data_seek(MYSQL_RES *result, uint64_t offset);
+MYSQL_ROW_OFFSET STDCALL mysql_row_seek(MYSQL_RES *result, MYSQL_ROW_OFFSET offset);
+MYSQL_FIELD_OFFSET STDCALL mysql_field_seek(MYSQL_RES *result, MYSQL_FIELD_OFFSET offset);
 MYSQL_ROW	STDCALL mysql_fetch_row(MYSQL_RES *result);
-unsigned long * STDCALL mysql_fetch_lengths(MYSQL_RES *result);
+uint32_t * STDCALL mysql_fetch_lengths(MYSQL_RES *result);
 MYSQL_FIELD *	STDCALL mysql_fetch_field(MYSQL_RES *result);
-MYSQL_RES *     STDCALL mysql_list_fields(MYSQL *mysql, const char *table,
-					  const char *wild);
-unsigned long	STDCALL mysql_escape_string(char *to,const char *from,
-					    unsigned long from_length);
-unsigned long	STDCALL mysql_hex_string(char *to,const char *from,
-                                         unsigned long from_length);
-unsigned long STDCALL mysql_real_escape_string(MYSQL *mysql,
-					       char *to,const char *from,
-					       unsigned long length);
+MYSQL_RES *     STDCALL mysql_list_fields(MYSQL *mysql, const char *table, const char *wild);
+uint32_t	STDCALL mysql_escape_string(char *to,const char *from, uint32_t from_length);
+uint32_t	STDCALL mysql_hex_string(char *to,const char *from, uint32_t from_length);
+uint32_t        STDCALL mysql_real_escape_string(MYSQL *mysql, char *to, const char *from, uint32_t length);
 void		STDCALL mysql_debug(const char *debug);
 void 		STDCALL myodbc_remove_escape(MYSQL *mysql,char *name);
-unsigned int	STDCALL mysql_thread_safe(void);
+uint32_t	STDCALL mysql_thread_safe(void);
 my_bool		STDCALL mysql_embedded(void);
 my_bool         STDCALL mysql_read_query_result(MYSQL *mysql);
 
@@ -429,25 +409,23 @@
 
 typedef struct st_mysql_methods
 {
-  my_bool (*read_query_result)(MYSQL *mysql);
-  my_bool (*advanced_command)(MYSQL *mysql,
-			      enum enum_server_command command,
-			      const unsigned char *header,
-			      unsigned long header_length,
-			      const unsigned char *arg,
-			      unsigned long arg_length,
-			      my_bool skip_check);
-  MYSQL_DATA *(*read_rows)(MYSQL *mysql,MYSQL_FIELD *mysql_fields,
-			   unsigned int fields);
+  bool (*read_query_result)(MYSQL *mysql);
+  bool (*advanced_command)(MYSQL *mysql,
+                           enum enum_server_command command,
+                           const unsigned char *header,
+                           uint32_t header_length,
+                           const unsigned char *arg,
+                           uint32_t arg_length,
+                           bool skip_check);
+  MYSQL_DATA *(*read_rows)(MYSQL *mysql,MYSQL_FIELD *mysql_fields, uint32_t fields);
   MYSQL_RES * (*use_result)(MYSQL *mysql);
-  void (*fetch_lengths)(unsigned long *to, 
-			MYSQL_ROW column, unsigned int field_count);
+  void (*fetch_lengths)(uint32_t *to, MYSQL_ROW column, uint32_t field_count);
   void (*flush_use_result)(MYSQL *mysql);
   MYSQL_FIELD * (*list_fields)(MYSQL *mysql);
-  int (*unbuffered_fetch)(MYSQL *mysql, char **row);
+  int32_t (*unbuffered_fetch)(MYSQL *mysql, char **row);
   const char *(*read_statistics)(MYSQL *mysql);
-  my_bool (*next_result)(MYSQL *mysql);
-  int (*read_change_user_result)(MYSQL *mysql, char *buff, const char *passwd);
+  bool (*next_result)(MYSQL *mysql);
+  int32_t (*read_change_user_result)(MYSQL *mysql, char *buff, const char *passwd);
 } MYSQL_METHODS;
 
 
@@ -465,14 +443,6 @@
 
 #define mysql_reload(mysql) mysql_refresh((mysql),REFRESH_GRANT)
 
-#ifdef USE_OLD_FUNCTIONS
-MYSQL *		STDCALL mysql_connect(MYSQL *mysql, const char *host,
-				      const char *user, const char *passwd);
-int		STDCALL mysql_create_db(MYSQL *mysql, const char *DB);
-int		STDCALL mysql_drop_db(MYSQL *mysql, const char *DB);
-#endif
-#define HAVE_MYSQL_REAL_CONNECT
-
 /*
   The following functions are mainly exported because of mysqlbinlog;
   They are not for general usage

=== modified file 'include/drizzle_com.h'
--- include/drizzle_com.h	2008-07-14 16:09:55 +0000
+++ include/drizzle_com.h	2008-07-15 08:57:01 +0000
@@ -366,18 +366,18 @@
 extern "C" {
 #endif
 
-my_bool	my_net_init(NET *net, Vio* vio);
+bool	my_net_init(NET *net, Vio* vio);
 void	my_net_local_init(NET *net);
 void	net_end(NET *net);
-  void	net_clear(NET *net, my_bool clear_buffer);
-my_bool net_realloc(NET *net, size_t length);
-my_bool	net_flush(NET *net);
-my_bool	my_net_write(NET *net,const unsigned char *packet, size_t len);
-my_bool	net_write_command(NET *net,unsigned char command,
+void	net_clear(NET *net, bool clear_buffer);
+bool    net_realloc(NET *net, size_t length);
+bool	net_flush(NET *net);
+bool	my_net_write(NET *net,const unsigned char *packet, size_t len);
+bool	net_write_command(NET *net,unsigned char command,
 			  const unsigned char *header, size_t head_len,
 			  const unsigned char *packet, size_t len);
-int	net_real_write(NET *net,const unsigned char *packet, size_t len);
-unsigned long my_net_read(NET *net);
+int32_t	net_real_write(NET *net,const unsigned char *packet, size_t len);
+uint32_t my_net_read(NET *net);
 
 #ifdef _global_h
 void my_net_set_write_timeout(NET *net, uint timeout);
@@ -445,18 +445,16 @@
   implemented in sql/password.c
 */
 
-void randominit(struct rand_struct *, unsigned long seed1,
-                unsigned long seed2);
+void randominit(struct rand_struct *, uint32_t seed1, uint32_t seed2);
 double my_rnd(struct rand_struct *);
 void create_random_string(char *to, unsigned int length, struct rand_struct *rand_st);
 
-void hash_password(unsigned long *to, const char *password, unsigned int password_len);
+void hash_password(uint32_t *to, const char *password, uint32_t password_len);
 void make_scrambled_password_323(char *to, const char *password);
 void scramble_323(char *to, const char *message, const char *password);
-my_bool check_scramble_323(const char *, const char *message,
-                           unsigned long *salt);
-void get_salt_from_password_323(unsigned long *res, const char *password);
-void make_password_from_salt_323(char *to, const unsigned long *salt);
+my_bool check_scramble_323(const char *, const char *message, uint32_t *salt);
+void get_salt_from_password_323(uint32_t *res, const char *password);
+void make_password_from_salt_323(char *to, const uint32_t *salt);
 
 void make_scrambled_password(char *to, const char *password);
 void scramble(char *to, const char *message, const char *password);

=== modified file 'include/sql_common.h'
--- include/sql_common.h	2008-07-02 21:16:23 +0000
+++ include/sql_common.h	2008-07-15 08:57:01 +0000
@@ -31,12 +31,11 @@
 my_bool mysql_reconnect(MYSQL *mysql);
 void mysql_read_default_options(struct st_mysql_options *options,
 				const char *filename,const char *group);
-my_bool
+bool
 cli_advanced_command(MYSQL *mysql, enum enum_server_command command,
-		     const unsigned char *header, ulong header_length,
-		     const unsigned char *arg, ulong arg_length,
-                     my_bool skip_check);
-unsigned long cli_safe_read(MYSQL *mysql);
+		     const unsigned char *header, uint32_t header_length,
+		     const unsigned char *arg, uint32_t arg_length, bool skip_check);
+uint32_t cli_safe_read(MYSQL *mysql);
 void net_clear_error(NET *net);
 void set_mysql_error(MYSQL *mysql, int errcode, const char *sqlstate);
 #ifdef	__cplusplus

=== modified file 'libdrizzle/client.c'
--- libdrizzle/client.c	2008-07-15 06:45:16 +0000
+++ libdrizzle/client.c	2008-07-15 08:57:01 +0000
@@ -320,8 +320,7 @@
   or packet is an error message
 *****************************************************************************/
 
-ulong
-cli_safe_read(MYSQL *mysql)
+uint32_t cli_safe_read(MYSQL *mysql)
 {
   NET *net= &mysql->net;
   ulong len=0;
@@ -403,10 +402,10 @@
   }
 }
 
-my_bool
+bool
 cli_advanced_command(MYSQL *mysql, enum enum_server_command command,
-		     const uchar *header, ulong header_length,
-		     const uchar *arg, ulong arg_length, my_bool skip_check)
+		     const unsigned char *header, uint32_t header_length,
+		     const unsigned char *arg, uint32_t arg_length, bool skip_check)
 {
   NET *net= &mysql->net;
   my_bool result= 1;
@@ -780,10 +779,9 @@
   else the lengths are calculated from the offset between pointers.
 **************************************************************************/
 
-static void cli_fetch_lengths(ulong *to, MYSQL_ROW column,
-			      unsigned int field_count)
+static void cli_fetch_lengths(uint32_t *to, MYSQL_ROW column, uint32_t field_count)
 { 
-  ulong *prev_length;
+  uint32_t *prev_length;
   char *start=0;
   MYSQL_ROW end;
 
@@ -812,7 +810,7 @@
 {
   MYSQL_ROWS	*row;
   MYSQL_FIELD	*field,*result;
-  ulong lengths[9];				/* Max of fields */
+  uint32_t lengths[9];				/* Max of fields */
   DBUG_ENTER("unpack_fields");
 
   field= result= (MYSQL_FIELD*) alloc_root(alloc,
@@ -1016,8 +1014,8 @@
 */
 
 
-static int
-read_one_row(MYSQL *mysql,uint fields,MYSQL_ROW row, ulong *lengths)
+static int32_t
+read_one_row(MYSQL *mysql, uint32_t fields, MYSQL_ROW row, uint32_t *lengths)
 {
   uint field;
   ulong pkt_len,len;
@@ -1134,64 +1132,12 @@
 
 #define strdup_if_not_null(A) (A) == 0 ? 0 : my_strdup((A),MYF(MY_WME))
 
-my_bool STDCALL
-mysql_ssl_set(MYSQL *mysql __attribute__((unused)) ,
-	      const char *key __attribute__((unused)),
-	      const char *cert __attribute__((unused)),
-	      const char *ca __attribute__((unused)),
-	      const char *capath __attribute__((unused)),
-	      const char *cipher __attribute__((unused)))
-{
-  DBUG_ENTER("mysql_ssl_set");
-  DBUG_RETURN(0);
-}
-
-
-/*
-  Free strings in the SSL structure and clear 'use_ssl' flag.
-  NB! Errors are not reported until you do mysql_real_connect.
-*/
-
-/*
-  Return the SSL cipher (if any) used for current
-  connection to the server.
-
-  SYNOPSYS
-    mysql_get_ssl_cipher()
-      mysql pointer to the mysql connection
-
-*/
-
-const char * STDCALL
-mysql_get_ssl_cipher(MYSQL *mysql __attribute__((unused)))
-{
-  DBUG_ENTER("mysql_get_ssl_cipher");
-  DBUG_RETURN(NULL);
-}
-
-
-/*
-  Check the server's (subject) Common Name against the
-  hostname we connected to
-
-  SYNOPSIS
-  ssl_verify_server_cert()
-    vio              pointer to a SSL connected vio
-    server_hostname  name of the server that we connected to
-
-  RETURN VALUES
-   0 Success
-   1 Failed to validate server
-
- */
-
-
 /*
   Note that the mysql argument must be initialized with mysql_init()
   before calling mysql_real_connect !
 */
 
-static my_bool cli_read_query_result(MYSQL *mysql);
+static bool cli_read_query_result(MYSQL *mysql);
 static MYSQL_RES *cli_use_result(MYSQL *mysql);
 
 static MYSQL_METHODS client_methods=
@@ -1286,11 +1232,11 @@
 MYSQL * STDCALL
 CLI_MYSQL_REAL_CONNECT(MYSQL *mysql,const char *host, const char *user,
                        const char *passwd, const char *db,
-                       uint port, const char *unix_socket,ulong client_flag)
+                       uint32_t port, const char *unix_socket, uint32_t client_flag)
 {
   char          buff[NAME_LEN+USERNAME_LENGTH+100];
   char          *end,*host_info=NULL;
-  ulong         pkt_length;
+  uint32_t         pkt_length;
   NET           *net= &mysql->net;
   struct        sockaddr_un UNIXaddr;
   init_sigpipe_variables
@@ -1973,7 +1919,7 @@
 }
 
 
-static my_bool cli_read_query_result(MYSQL *mysql)
+static bool cli_read_query_result(MYSQL *mysql)
 {
   uchar *pos;
   ulong field_count;
@@ -2051,19 +1997,19 @@
   finish processing it.
 */
 
-int STDCALL
-mysql_send_query(MYSQL* mysql, const char* query, ulong length)
+int32_t STDCALL
+mysql_send_query(MYSQL* mysql, const char* query, uint32_t length)
 {
   DBUG_ENTER("mysql_send_query");
   DBUG_RETURN(simple_command(mysql, COM_QUERY, (uchar*) query, length, 1));
 }
 
 
-int STDCALL
-mysql_real_query(MYSQL *mysql, const char *query, ulong length)
+int32_t STDCALL
+mysql_real_query(MYSQL *mysql, const char *query, uint32_t length)
 {
   DBUG_ENTER("mysql_real_query");
-  DBUG_PRINT("enter",("handle: 0x%lx", (long) mysql));
+  DBUG_PRINT("enter",("handle: 0x%lx", (int32_t) mysql));
   DBUG_PRINT("query",("Query = '%-.4096s'",query));
 
   if (mysql_send_query(mysql,query,length))
@@ -2099,8 +2045,8 @@
     DBUG_RETURN(0);
   }
   result->methods= mysql->methods;
-  result->eof=1;				/* Marker for buffered */
-  result->lengths=(ulong*) (result+1);
+  result->eof= 1;				/* Marker for buffered */
+  result->lengths= (uint32_t*) (result+1);
   if (!(result->data=
 	(*mysql->methods->read_rows)(mysql,mysql->fields,mysql->field_count)))
   {
@@ -2147,7 +2093,7 @@
 				      sizeof(ulong)*mysql->field_count,
 				      MYF(MY_WME | MY_ZEROFILL))))
     DBUG_RETURN(0);
-  result->lengths=(ulong*) (result+1);
+  result->lengths=(uint32_t*) (result+1);
   result->methods= mysql->methods;
   if (!(result->row=(MYSQL_ROW)
 	my_malloc(sizeof(result->row[0])*(mysql->field_count+1), MYF(MY_WME))))
@@ -2228,7 +2174,7 @@
   else the lengths are calculated from the offset between pointers.
 **************************************************************************/
 
-ulong * STDCALL
+uint32_t * STDCALL
 mysql_fetch_lengths(MYSQL_RES *res)
 {
   MYSQL_ROW column;
@@ -2373,7 +2319,7 @@
    Signed number > 323000
 */
 
-ulong STDCALL
+uint32_t STDCALL
 mysql_get_server_version(MYSQL *mysql)
 {
   uint major, minor, version;

=== modified file 'libdrizzle/libdrizzle.c'
--- libdrizzle/libdrizzle.c	2008-07-15 06:45:16 +0000
+++ libdrizzle/libdrizzle.c	2008-07-15 08:57:01 +0000
@@ -63,8 +63,8 @@
 #undef net_buffer_length
 #undef max_allowed_packet
 
-ulong 		net_buffer_length=8192;
-ulong		max_allowed_packet= 1024L*1024L*1024L;
+uint32_t 		net_buffer_length= 8192;
+uint32_t		max_allowed_packet= 1024L*1024L*1024L;
 
 #include <errno.h>
 #define SOCKET_ERROR -1
@@ -409,7 +409,7 @@
   }
 
   /* Write authentication package */
-  simple_command(mysql,COM_CHANGE_USER, (uchar*) buff, (ulong) (end-buff), 1);
+  (void)simple_command(mysql,COM_CHANGE_USER, (uchar*) buff, (ulong) (end-buff), 1);
 
   rc= (*mysql->methods->read_change_user_result)(mysql, buff, passwd);
 
@@ -931,8 +931,8 @@
 }
 
 
-int STDCALL
-mysql_kill(MYSQL *mysql,ulong pid)
+int32_t STDCALL
+mysql_kill(MYSQL *mysql, uint32_t pid)
 {
   uchar buff[4];
   DBUG_ENTER("mysql_kill");
@@ -1019,7 +1019,7 @@
   return (char*) MYSQL_SERVER_VERSION;
 }
 
-ulong STDCALL mysql_get_client_version(void)
+uint32_t STDCALL mysql_get_client_version(void)
 {
   return MYSQL_VERSION_ID;
 }
@@ -1071,7 +1071,7 @@
   return mysql ? mysql->net.sqlstate : cant_connect_sqlstate;
 }
 
-uint STDCALL mysql_warning_count(MYSQL *mysql)
+uint32_t STDCALL mysql_warning_count(MYSQL *mysql)
 {
   return mysql->warning_count;
 }
@@ -1081,7 +1081,7 @@
   return mysql->info;
 }
 
-ulong STDCALL mysql_thread_id(MYSQL *mysql)
+uint32_t STDCALL mysql_thread_id(MYSQL *mysql)
 {
   return (mysql)->thread_id;
 }
@@ -1159,8 +1159,8 @@
   trailing '. The caller must supply whichever of those is desired.
 */
 
-ulong STDCALL
-mysql_hex_string(char *to, const char *from, ulong length)
+uint32_t STDCALL
+mysql_hex_string(char *to, const char *from, uint32_t length)
 {
   char *to0= to;
   const char *end;
@@ -1171,7 +1171,7 @@
     *to++= _dig_vec_upper[((unsigned char) *from) & 0x0F];
   }
   *to= '\0';
-  return (ulong) (to-to0);
+  return (uint32_t) (to-to0);
 }
 
 /*
@@ -1180,15 +1180,15 @@
   Returns the length of the to string
 */
 
-ulong STDCALL
-mysql_escape_string(char *to,const char *from,ulong length)
+uint32_t STDCALL
+mysql_escape_string(char *to,const char *from, uint32_t length)
 {
   return escape_string_for_mysql(default_charset_info, to, 0, from, length);
 }
 
-ulong STDCALL
+uint32_t STDCALL
 mysql_real_escape_string(MYSQL *mysql, char *to,const char *from,
-			 ulong length)
+			 uint32_t length)
 {
   if (mysql->server_status & SERVER_STATUS_NO_BACKSLASH_ESCAPES)
     return escape_quotes_for_mysql(mysql->charset, to, 0, from, length);

=== modified file 'libdrizzle/net_serv.c'
--- libdrizzle/net_serv.c	2008-07-15 06:45:16 +0000
+++ libdrizzle/net_serv.c	2008-07-15 08:57:01 +0000
@@ -49,12 +49,12 @@
 #define TEST_BLOCKING		8
 #define MAX_PACKET_LENGTH (256L*256L*256L-1)
 
-static my_bool net_write_buff(NET *net,const uchar *packet,ulong len);
+static bool net_write_buff(NET *net, const unsigned char *packet, uint32_t len);
 
 
 /** Init with packet info. */
 
-my_bool my_net_init(NET *net, Vio* vio)
+bool my_net_init(NET *net, Vio* vio)
 {
   DBUG_ENTER("my_net_init");
   net->vio = vio;
@@ -93,7 +93,7 @@
 
 /** Realloc the packet buffer. */
 
-my_bool net_realloc(NET *net, size_t length)
+bool net_realloc(NET *net, size_t length)
 {
   uchar *buff;
   size_t pkt_length;
@@ -196,10 +196,10 @@
   @param clear_buffer           if <> 0, then clear all data from comm buff
 */
 
-void net_clear(NET *net, my_bool clear_buffer)
+void net_clear(NET *net, bool clear_buffer)
 {
   size_t count;
-  int ready;
+  int32_t ready;
   DBUG_ENTER("net_clear");
 
   if (clear_buffer)
@@ -245,7 +245,7 @@
 
 /** Flush write_buffer if not empty. */
 
-my_bool net_flush(NET *net)
+bool net_flush(NET *net)
 {
   my_bool error= 0;
   DBUG_ENTER("net_flush");
@@ -276,7 +276,7 @@
     If compression is used the original package is modified!
 */
 
-my_bool
+bool
 my_net_write(NET *net,const uchar *packet,size_t len)
 {
   uchar buff[NET_HEADER_SIZE];
@@ -336,7 +336,7 @@
     1	error
 */
 
-my_bool
+bool
 net_write_command(NET *net,uchar command,
 		  const uchar *header, size_t head_len,
 		  const uchar *packet, size_t len)
@@ -402,8 +402,8 @@
     1
 */
 
-static my_bool
-net_write_buff(NET *net, const uchar *packet, ulong len)
+static bool
+net_write_buff(NET *net, const unsigned char *packet, uint32_t len)
 {
   ulong left_length;
   if (net->compress && net->max_packet > MAX_PACKET_LENGTH)
@@ -725,7 +725,7 @@
   net->read_pos points to the read data.
 */
 
-ulong
+uint32_t
 my_net_read(NET *net)
 {
   size_t len, complen;

=== modified file 'libdrizzle/password.c'
--- libdrizzle/password.c	2008-07-09 19:33:54 +0000
+++ libdrizzle/password.c	2008-07-15 08:57:01 +0000
@@ -75,7 +75,7 @@
     seed2      IN   Second initialization parameter
 */
 
-void randominit(struct rand_struct *rand_st, ulong seed1, ulong seed2)
+void randominit(struct rand_struct *rand_st, uint32_t seed1, uint32_t seed2)
 {                                               /* For mysql 3.21.# */
 #ifdef HAVE_purify
   bzero((char*) rand_st,sizeof(*rand_st));      /* Avoid UMC varnings */
@@ -114,22 +114,22 @@
     password_len IN  password length (password may be not null-terminated)
 */
 
-void hash_password(ulong *result, const char *password, uint password_len)
+void hash_password(uint32_t *result, const char *password, uint32_t password_len)
 {
   register ulong nr=1345345333L, add=7, nr2=0x12345671L;
-  ulong tmp;
+  uint32_t tmp;
   const char *password_end= password + password_len;
   for (; password < password_end; password++)
   {
     if (*password == ' ' || *password == '\t')
       continue;                                 /* skip space in password */
-    tmp= (ulong) (uchar) *password;
+    tmp= (uint32_t) (uchar) *password;
     nr^= (((nr & 63)+add)*tmp)+ (nr << 8);
     nr2+=(nr2 << 8) ^ nr;
     add+=tmp;
   }
-  result[0]=nr & (((ulong) 1L << 31) -1L); /* Don't use sign bit (str2int) */;
-  result[1]=nr2 & (((ulong) 1L << 31) -1L);
+  result[0]=nr & (((uint32_t) 1L << 31) -1L); /* Don't use sign bit (str2int) */;
+  result[1]=nr2 & (((uint32_t) 1L << 31) -1L);
 }
 
 
@@ -146,7 +146,7 @@
 {
   ulong hash_res[2];
   hash_password(hash_res, password, (uint) strlen(password));
-  sprintf(to, "%08lx%08lx", hash_res[0], hash_res[1]);
+  sprintf(to, "%08x%08x", hash_res[0], hash_res[1]);
 }
 
 
@@ -203,8 +203,7 @@
 */
 
 my_bool
-check_scramble_323(const char *scrambled, const char *message,
-                   ulong *hash_pass)
+check_scramble_323(const char *scrambled, const char *message, uint32_t *hash_pass)
 {
   struct rand_struct rand_st;
   ulong hash_message[2];
@@ -248,7 +247,7 @@
     Password hashes in old format must have length divisible by 8
 */
 
-void get_salt_from_password_323(ulong *res, const char *password)
+void get_salt_from_password_323(uint32_t *res, const char *password)
 {
   res[0]= res[1]= 0;
   if (password)
@@ -273,9 +272,9 @@
     salt  IN  password in salt format, 2 ulongs 
 */
 
-void make_password_from_salt_323(char *to, const ulong *salt)
+void make_password_from_salt_323(char *to, const uint32_t *salt)
 {
-  sprintf(to,"%08lx%08lx", salt[0], salt[1]);
+  sprintf(to,"%08x%08x", salt[0], salt[1]);
 }
 
 

=== modified file 'server/sql_crypt.cc'
--- server/sql_crypt.cc	2008-06-25 05:29:13 +0000
+++ server/sql_crypt.cc	2008-07-15 08:57:01 +0000
@@ -30,14 +30,14 @@
 
 SQL_CRYPT::SQL_CRYPT(const char *password)
 {
-  ulong rand_nr[2];
-  hash_password(rand_nr,password, strlen(password));
+  uint32_t rand_nr[2];
+  hash_password(rand_nr, password, strlen(password));
   crypt_init(rand_nr);
 }
 
-void SQL_CRYPT::crypt_init(ulong *rand_nr)
+void SQL_CRYPT::crypt_init(uint32_t *rand_nr)
 {
-  uint i;
+  uint32_t i;
   randominit(&rand,rand_nr[0],rand_nr[1]);
 
   for (i=0 ; i<=255; i++)
@@ -57,25 +57,25 @@
 }
 
 
-void SQL_CRYPT::encode(char *str,uint length)
+void SQL_CRYPT::encode(char *str, uint32_t length)
 {
-  for (uint i=0; i < length; i++)
+  for (uint32_t i=0; i < length; i++)
   {
-    shift^=(uint) (my_rnd(&rand)*255.0);
-    uint idx= (uint) (uchar) str[0];
+    shift^=(uint32_t) (my_rnd(&rand)*255.0);
+    uint32_t idx= (uint) (uchar) str[0];
     *str++ = (char) ((uchar) encode_buff[idx] ^ shift);
     shift^= idx;
   }
 }
 
 
-void SQL_CRYPT::decode(char *str,uint length)
+void SQL_CRYPT::decode(char *str, uint32_t length)
 {
-  for (uint i=0; i < length; i++)
+  for (uint32_t i=0; i < length; i++)
   {
-    shift^=(uint) (my_rnd(&rand)*255.0);
-    uint idx= (uint) ((uchar) str[0] ^ shift);
+    shift^=(uint32_t) (my_rnd(&rand)*255.0);
+    uint32_t idx= (uint32_t) ((uchar) str[0] ^ shift);
     *str = decode_buff[idx];
-    shift^= (uint) (uchar) *str++;
+    shift^= (uint32_t) (uchar) *str++;
   }
 }

=== modified file 'server/sql_crypt.h'
--- server/sql_crypt.h	2008-06-25 05:29:13 +0000
+++ server/sql_crypt.h	2008-07-15 08:57:01 +0000
@@ -22,16 +22,16 @@
 {
   struct rand_struct rand,org_rand;
   char decode_buff[256],encode_buff[256];
-  uint shift;
-  void crypt_init(ulong *seed);
+  uint32_t shift;
+  void crypt_init(uint32_t *seed);
  public:
   SQL_CRYPT(const char *seed);
-  SQL_CRYPT(ulong *seed)
+  SQL_CRYPT(uint32_t *seed)
   {
     crypt_init(seed);
   }
   ~SQL_CRYPT() {}
   void init() { shift=0; rand=org_rand; }
-  void encode(char *str, uint length);
-  void decode(char *str, uint length);
+  void encode(char *str, uint32_t length);
+  void decode(char *str, uint32_t length);
 };

